.. SPDX-FileCopyrightText: 2023 GSI Helmholtzzentrum fuer Schwerionenforschung GmbH, Darmstadt, Germany
..
.. SPDX-License-Identifier: LGPL-3.0-only

ti package
==========

.. automodule:: ti
   :members:
   :undoc-members:
   :show-inheritance:

.. toctree::
   :maxdepth: 1

   ti.ina238
